@@ -489,15 +489,14 @@ class DataTransformerForm(BaseInlineFormSet):
     def add_fields(self, form, index):
         super(DataTransformerForm, self).add_fields(form, index)
 
-        if hasattr(form.instance,'get_children'):
+        if hasattr(form.instance,'is_root_node') and form.instance.is_root_node():
             dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,formset=self.__class__,
-                                                                 fk_name='parent',
-                                                                 extra=1, form=DataTransform
+                                                                 fk_name='parent', form=DataTransform, extra=0
                                                                  )
             form.nested_data_transformer_form = dataTransformerInlineFormset(
-                instance=form.instance,
                 data=form.data if form.is_bound else None,
-                files=form.files if form.is_bound else None
+                files=form.files if form.is_bound else None,
+                initial = [{'parent': form.instance}]
             )
 
 
